import request from "string-public-design-3/utils/request";

import { FRAMEWORK_CORE_SERVICE } from "string-public-design-3/constants/location"
/**
 * 获取群组列表
 * @param {*} params
 */
export function queryGroup(params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/`,
        method: 'get',
        params
    })
}

/**
 * 获取群组实例
 * @param {*} groupId
 */
export function getGroup(groupId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/${groupId}/`,
        method: 'get',
    })
}

/**
 * 创建群组
 * @param {*} data
 */
export function createGroup(data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/create/`,
        method: 'post',
        data
    })
}

/**
 * 修改群组
 * @param {*} data
 *  @param {*} groupId
 */
export function updateGroup(groupId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/${groupId}/update/`,
        method: 'post',
        data
    })
}

/**
 * 删除群组
 * @param {*} groupId
 */
export function deleteGroup(groupId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/${groupId}/delete/`,
        method: 'post',
    })
}


/**
 * 查询群组人员
 * @param {*} groupId
 */
export function queryGroupUsers(groupId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/${groupId}/users/`,
        method: 'get',
        params
    })
}

/**
 * 新增群组人员
 * @param {*} groupId
 */
export function addGroupUser(groupId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/${groupId}/users/add/`,
        method: 'post',
        data
    })
}

/**
 * 批量新增群组人员
 * @param {*} groupId
 */
export function bindGroupUsers(groupId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/${groupId}/users/bind/`,
        method: 'post',
        data
    })
}

/**
 * 移除群组人员
 * @param {*} groupId
 */
export function removeGroupUser(groupId,userId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/${groupId}/users/${userId}/remove/`,
        method: 'post',
    })
}

/**
 * 清空群组人员
 * @param {*} groupId
 */
export function clearGroupUser(groupId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/groups/${groupId}/users/clear/`,
        method: 'post',
    })
}

