import request from "string-public-design-3/utils/request";

import { FRAMEWORK_CORE_SERVICE } from "string-public-design-3/constants/location"
/**
 * 获取组织列表
 * @param {*} params
 */
export function queryOrg(params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/`,
        method: 'get',
        params
    })
}

/**
 * 获取组织树形结构
 * @param {*} params
 */
export function queryOrgTree(params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/tree/`,
        method: 'get',
        params
    })
}

/**
 * 获取组织实例
 * @param {*} orgId
 */
export function getOrg(orgId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/`,
        method: 'get',
    })
}

/**
 * 创建组织
 * @param {*} data
 */
export function createOrg(data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/create/`,
        method: 'post',
        data
    })
}

/**
 * 修改组织
 * @param {*} data
 *  @param {*} orgId
 */
export function updateOrg(orgId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/update/`,
        method: 'post',
        data
    })
}

/**
 * 删除组织
 * @param {*} orgId
 */
export function deleteOrg(orgId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/delete/`,
        method: 'post',
    })
}


/**
 * 启用组织
 * @param {*} orgId 
 */
 export function enableOrg(orgId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/set_enable/`,
        method: 'post',
    })
}


/**
 * 禁用组织
 * @param {*} orgId 
 */
export function disableOrg(orgId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/set_disable/`,
        method: 'post',
    })
}


/**
 * 查询组织人员
 * @param {*} orgId
 */
export function queryOrgUsers(orgId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/users/`,
        method: 'get',
        params
    })
}

/**
 * 新增组织人员
 * @param {*} orgId
 */
export function addOrgUser(orgId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/users/add/`,
        method: 'post',
        data
    })
}

/**
 * 批量新增组织人员
 * @param {*} orgId
 */
export function bindOrgUsers(orgId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/users/bind/`,
        method: 'post',
        data
    })
}

/**
 * 移除组织人员
 * @param {*} orgId
 */
export function removeOrgUser(orgId,userId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/users/${userId}/remove/`,
        method: 'post',
    })
}

/**
 * 清空组织人员
 * @param {*} orgId
 */
export function clearOrgUser(orgId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/users/clear/`,
        method: 'post',
    })
}


/**
 * 查询组织自带角色
 * @param {*} orgId
 */
 export function queryOrgRoles(orgId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/roles/`,
        method: 'get',
        params
    })
}

/**
 * 新增组织自带角色
 * @param {*} orgId
 */
export function addOrgRole(orgId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/roles/add/`,
        method: 'post',
        data
    })
}

/**
 * 批量新增组织自带角色
 * @param {*} orgId
 */
export function bindOrgRoles(orgId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/roles/bind/`,
        method: 'post',
        data
    })
}

/**
 * 移除组织自带角色
 * @param {*} orgId
 */
export function removeOrgRole(orgId, roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/roles/${roleId}/remove/`,
        method: 'post',
    })
}

/**
 * 清空组织自带角色
 * @param {*} orgId
 */
export function clearOrgRole(orgId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/${orgId}/roles/clear/`,
        method: 'post',
    })
}


/**                      
* 同步组织信息
* @param {*} data
*/
export function syncOrg(data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/orgs/sync/`,
        method: 'post',
        data
    })
}
