import request from "string-public-design-3/utils/request";

import { FRAMEWORK_CORE_SERVICE } from "string-public-design-3/constants/location"

/** 
* 获取角色列表
* @param {*} params
*/
export function queryRole(params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/`,
        method: 'get',
        params
    })
}

/** 
* 获取单个角色
* @param {*} roleId
*/
export function getRole(roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/`,
        method: 'get',
    })
}

/** 
* 创建角色
* @param {*} data
*/
export function createRole(data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/create/`,
        method: 'post',
        data
    })
}

/** 
* 修改角色
* @param {*} roleId
 * @param {*} data 
*/
export function updateRole(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/update/`,
        method: 'post',
        data
    })
}

/** 
* 删除角色
* @param {*} roleId
*/
export function deleteRole(roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/delete/`,
        method: 'post',
    })
}


/**
 * 启用角色
 * @param {*} roleId 
 */
 export function enableRole(roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/set_enable/`,
        method: 'post',
    })
}


/**
 * 禁用角色
 * @param {*} roleId 
 */
export function disableRole(roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/set_disable/`,
        method: 'post',
    })
}

/**
 * get the role's user list
 * @param {*} roleId 
 * @param {*} params 
 * @returns 
 */
export function queryRoleUsers(roleId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/users/`,
        method: 'get',
        params
    })
}

/**
 * add role's user
 * @param {*} roleId 
 * @param {*} userId 
 * @returns 
 */
 export function addRoleUser(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/users/add/`,
        method: 'post',
        data
    })
}

/**
 * batch add role's user
 * @param {*} roleId 
 * @param {*} data 
 * @returns 
 */
 export function bindRoleUsers(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/users/bind/`,
        method: 'post',
        data
    })
}

/**
 * remove role user
 * @param {*} roleId 
 * @param {*} data 
 * @returns 
 */
export function removeRoleUser(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/users/remove/`,
        method: 'post',
        data
    })
}

/**
 * clear role user
 * @param {*} roleId 
 * @returns 
 */
 export function clearRoleUser(roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/users/clear/`,
        method: 'post',
    })
}



/**
 * query the manager roles
 * @param {*} roleId 
 */
 export function queryRoleManagers(roleId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/managers/`,
        method: 'get',
        params
    })
}


/**
 * add the manager role
 * @param {*} roleId 
 */
 export function addRoleManager(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/managers/add/`,
        method: 'post',
        data
    })
}


/**
 * batch add the role managers
 * @param {*} data 
 */
export function bindRoleManagers(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/managers/bind/`,
        method: 'post',
        data
    })
}


/**
 * remove the role manager
 * @param {*} roleId 
 */
export function removeRoleManager(roleId, managerId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/managers/${managerId}/remove/`,
        method: 'post',
    })
}


/**
 * 查询被管理的角色列表
 * @param {*} orgId 
 */
export function queryRoleEmployees(roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/employees/`,
        method: 'get',
    })
}

/**
 * get the role's recommend app list
 * @param {*} roleId 
 * @param {*} params 
 * @returns 
 */
 export function queryRoleRecommendApps(roleId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/recommend_apps/`,
        method: 'get',
        params
    })
}

/**
 * add role's recommend app
 * @param {*} roleId 
 * @param {*} appId 
 * @returns 
 */
 export function addRoleRecommendApp(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/recommend_apps/add/`,
        method: 'post',
        data
    })
}

/**
 * batch add role's recommend app 
 * @param {*} roleId 
 * @param {*} data 
 * @returns 
 */
 export function bindRoleRecommendApps(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/recommend_apps/bind/`,
        method: 'post',
        data
    })
}

/**
 * remove role recommend app 
 * @param {*} roleId 
 * @param {*} appId 
 * @returns 
 */
export function removeRoleRecommendApp(roleId, appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/recommend_apps/${appId}/remove/`,
        method: 'post',
    })
}

/**
 * clear role recommend app 
 * @param {*} roleId 
 * @returns 
 */
 export function clearRoleRecommendApp(roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/recommend_apps/clear/`,
        method: 'post',
    })
}


/**
 * query the role's assigned app list
 * @param {*} roleId 
 * @param {*} params 
 * @returns 
 */
 export function queryRoleApps(roleId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/apps/`,
        method: 'get',
        params
    })
}

/**
 * add role's assigned app
 * @param {*} roleId 
 * @param {*} appId 
 * @returns 
 */
 export function addRoleApp(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/apps/add/`,
        method: 'post',
        data
    })
}

/**
 * batch add role's assigned app 
 * @param {*} roleId 
 * @param {*} data 
 * @returns 
 */
 export function bindRoleApps(roleId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/apps/bind/`,
        method: 'post',
        data
    })
}

/**
 * remove role assigned app 
 * @param {*} roleId 
 * @param {*} appId 
 * @returns 
 */
export function removeRoleApp(roleId, appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/apps/${appId}/remove/`,
        method: 'post',
    })
}

/**
 * clear role assigned app 
 * @param {*} roleId 
 * @returns 
 */
 export function clearRoleApp(roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/roles/${roleId}/apps/clear/`,
        method: 'post',
    })
}


