import request from "string-public-design-3/utils/request";

import { FRAMEWORK_CORE_SERVICE } from "string-public-design-3/constants/location"

/**
 * 查询用户列表
 * @param {*} params
 */
export function queryUser(params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/`,
        method: 'get',
        params
    })
}
/**
 * 获取单个用户
 * @param {*} userId 
 */
export function getUser(userId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/`,
        method: 'get',
    })
}


/**
 * 创建用户
 * @param {*} data 
 */
export function createUser(data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/create/`,
        method: 'post',
        data
    })
}

/**
 * 修改用户
 * @param {*} userId 
 * @param {*} data 
 */
export function updateUser(userId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/update/`,
        method: 'post',
        data
    })
}


/**
 * 删除用户
 * @param {*} userId 
 */
export function deleteUser(userId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/delete/`,
        method: 'post',
    })
}


/**
 * 启用用户
 * @param {*} userId 
 */
export function enableUser(userId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/set_enable/`,
        method: 'post',
    })
}


/**
 * 禁用用户
 * @param {*} userId 
 */
export function disableUser(userId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/set_disable/`,
        method: 'post',
    })
}

/**
 * 修改密码
 * @param {*} userId 
 * @param {*} data 
 */
 export function setUserPassword(userId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/set_password/`,
        method: 'post',
        data
    })
}

/**
 * 重置密码
 * @param {*} data 
 */
 export function resetUserPassword(userId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/reset_password/`,
        method: 'post',
        data
    })
}



/**
 * 获取用户的角色
 * @param {*} userId 
 */
export function queryUserRoles(userId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/roles/`,
        method: 'get',
        params
    })
}

/**
* 批量绑定角色
* @param {*} data
*/
export function bindUserRoles(userId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/roles/bind/`,
        method: 'post',
        data
    })
}



/**                      
* 移除的单个角色
* @param {*} data
*/
export function removeUserRole(userId,roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/roles/${roleId}/remove/`,
        method: 'post',
    })
}

/**
 * 获取用户的管理的角色
 * @param {*} userId 
 */
 export function queryUserManageRoles(userId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/manage_roles/`,
        method: 'get',
        params
    })
}





/**
 * 获取用户的部门
 * @param {*} userId 
 */
 export function queryUserOrgs(userId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/orgs/`,
        method: 'get',
        params:{}
    })
}

/**
* 批量绑定的部门
* @param {*} data
*/
export function bindUserOrgs(userId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/orgs/bind/`,
        method: 'post',
        data
    })
}


/**                      
* 移除的单个部门
* @param {*} data
*/
export function removeUserOrg(userId,orgId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/orgs/${orgId}/remove/`,
        method: 'post',
    })
}


/**                      
* 根据用户获取班主任管理的班级，学生则获取所在班级
* @param {*} params
*/
export function queryUserClasses(userId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/classes/`,
        method: 'get',
    })
}


/**                      
* 批量导入头像
* @param {*} data
*/
export function batchImportUserAvatarURL(data) {
    return `${window.string.SERVICE_HOST}${FRAMEWORK_CORE_SERVICE}/users/batch_upload_avatar/`;
}

/**
 * 获取用户的集合应用
 * @param {*} userId 
 */
 export function queryUserUnitedApp(userId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/united_apps/`,
        method: 'get',
        params
    })
}

/**
 * 获取用户所能管理的应用
 * @param {*} userId 
 */
 export function queryUserManageApp(userId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/manage_apps/`,
        method: 'get',
        params
    })
}

/**                      
* 同步用户信息
* @param {*} data
*/
export function syncUser(data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/sync/`,
        method: 'post',
        data
    })
}

/**
 * 获取用户的菜单
 * @param {*} userId 
 */
 export function queryUserMenus(userId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/users/${userId}/menus/`,
        method: 'get',
        params
    })
}


