import request from "string-public-design-3/utils/request";

import { FRAMEWORK_CORE_SERVICE } from "string-public-design-3/constants/location"

/**
 * 获取列表
 * @param {*} params
 */
export function queryApp(params = {}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/`,
        method: 'get',
        params
    })
}

/**
 * 树形结构
 * @param {*} 
 */
export function getAppTree(params = {}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/tree/`,
        method: 'get',
        params
    })
}

/**
 * 获取单个应用
 * @param {*} appId
 */
export function getApp(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/`,
        method: 'get',
    })
}

/**
 * 根据Key获取应用
 * @param {*} appKey
 */
export function getAppByKey(appKey) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appKey}/get_info_by_key/`,
        method: 'get',
    })
}

/**
 * 创建
 * @param {*} data
 */
export function createApp(data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/create/`,
        method: 'post',
        data
    })
}

/**
 * 编辑
 * @param {*} appId
 * @param {*} data
 */
export function updateApp(appId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/update/`,
        method: 'post',
        data
    })
}

/**
 * 删除
 * @param {*} appId
 */
export function deleteApp(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/delete/`,
        method: 'post',
    })
}


/**
 * 设置PC端可用
 * @param {*} appId
 */
export function setAppPCEnable(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/enable_pc/`,
        method: 'post',
    })
}

/**
 * 设置PC端不可用
 * @param {*} appId
 */
 export function setAppPCDisable(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/disable_pc/`,
        method: 'post',
    })
}

/**
 * 设置移动端可用
 * @param {*} appId
 */
export function setAppMobileEnable(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/enable_mobile/`,
        method: 'post',
    })
}

/**
 * 设置移动端不可用
 * @param {*} appId
 */
export function setAppMobileDisable(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/disable_mobile/`,
        method: 'post',
    })
}


/**
 * 显示角标
 * @param {*} appId
 */
export function showAppBadge(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/show_badge/`,
        method: 'post',
    })
}

/**
 * 隐藏角标
 * @param {*} appId
 */
 export function hideAppBadge(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/hide_badge/`,
        method: 'post',
    })
}

/**
 * 显示指南
 * @param {*} appId
 */
export function showAppGuide(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/show_guide/`,
        method: 'post',
    })
}

/**
 * 隐藏指南
 * @param {*} appId
 */
 export function hideAppGuide(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/hide_guide/`,
        method: 'post',
    })
}

/**
 * 收藏
 * @param {*} appId
 */
 export function saveApp(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/save/`,
        method: 'post',
    })
}
/**
 * 取消收藏
 * @param {*} appId
 */
export function cancelSaveApp(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/cancel_save/`,
        method: 'post',
    })
}

/**
 * 以角色为分组查看相应的权限配置
 * @param {*} appId
 */
 export function queryAppPermsGroupByRole(appId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/get_perms_group_by_role/`,
        method: 'get',
        params
    })
}

/**
 * 查看应用的权限
 * @param {*} appId
 */
export function queryAppPerms(appId, params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/perms/`,
        method: 'get',
        params
    })
}

/**
 * 新增应用的权限
 * @param {*} appId
 * @param {*} data
 */
 export function addAppPerm(appId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/perms/add/`,
        method: 'post',
        data
    })
}
/**
 * 批量新增应用的权限
 * @param {*} appId
 */
export function bindAppPerms(appId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/perms/bind/`,
        method: 'post',
        data
    })
}

/**
 * 解除应用的权限
 * @param {*} appId
 * @param {*} permId
 */
 export function removeAppPerm(appId, permId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/perms/${permId}/remove/`,
        method: 'post',
    })
}




/**
 * 查看应用的角色
 * @param {*} appId
 */
export function queryAppRoles(appId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/roles/`,
        method: 'get',
    })
}

/**
 * 新增应用的角色
 * @param {*} appId
 * @param {*} data
 */
export function addAppRole(appId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/roles/add/`,
        method: 'post',
        data
    })
}

/**
 * 批量新增应用的角色
 * @param {*} appId
 * @param {*} data
 */
export function bindAppRoles(appId, data) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/roles/bind/`,
        method: 'post',
        data
    })
}

/**
 * 解除应用的角色
 * @param {*} appId
 * @param {*} roleId
 */
export function removeAppRole(appId, roleId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/roles/${roleId}/remove/`,
        method: 'post',
    })
}


/**
 * 新增应用角色的权限
 * @param {*} appId
 * @param {*} rorleId
 * @param {*} permId
 */
export function addAppRolePerm(appId, rorleId, permId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/roles/${rorleId}/perms/${permId}/add/`,
        method: 'post',
    })
}
/**
 * 解除应用角色的权限
 * @param {*} appId
 * @param {*} rorleId
 * @param {*} permId
 */
export function removeAppRolePerm(appId, rorleId, permId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/apps/${appId}/roles/${rorleId}/perms/${permId}/remove/`,
        method: 'post',
    })
}











