import request from "string-public-design-3/utils/request";
import requestIBPS from "string-public-design-3/utils/request-ibps";

import {FRAMEWORK_AUTH_SERVICE} from "string-public-design-3/constants/location"


/**
 * 移动端登录
 */
export function mobileLogin(params) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/wechat/login/`,
        method: 'get',
        params
    })
}

/**
 * 账号密码登录
 * @param {account, password} data
 */
export function login(data) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/login/`,
        method: 'post',
        data
    })
}

/**
 * 使用微信code登录
 * @param {appId, wechatCode} data
 */
export function loginWechat(data) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/wechat/`,
        method: 'post',
        data
    })
}

/**
 * 使用钉钉code登录
 * @param {dingCode} params
 */
export function loginDing(params) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/ding/login/`,
        method: 'get',
        params
    })
}

/**
 * 单点登录，根据ticket登录
 * @param {ticket} params
 */
export function loginSSO(params) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/sso/`,
        method: 'get',
        params
    })
}

/**
 * 移动端单点登录
 * @param {token} data
 */
export function loginMobileSSO(data) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/mobile/sso/`,
        method: 'post',
        data
    })
}

/**
 * 注销
 */
export function logout() {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/ticket/sso/logout/`,
        method: 'get'
    })
}

/**
 * 查看token是否过期
 */
export function checkTokenValiation() {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/check_token_validation/`,
        method: 'get'
    })
}

/**
 * 验证cas登录是否过期
 * @param {domain, path, sessionId} params
 */
export function checkCasLoginValiation(params) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/ticket/tes/`,
        method: 'get',
        params
    })
}

/**
 * 查看ibpsToken是否过期
 */
export function checkIBPSTokenValidation(token) {
    return requestIBPS({
        url: `/authentication/verify/?access_token=${token}`,
        method: 'post'
    })
}


/**
 * 获取登录状态state
 * @param {reqUrl, serviceTicket} data
 */
export function getLoginStateByTicket(data) {
    return requestIBPS({
        url: `user/login/auth`,
        method: 'post',
        data
    })
}

/**
 * 获取authcode
 * @param login_state
 */
export function getLoginAuthCodeByLoginState(login_state) {
    return requestIBPS({
        url: `authorize/apply`,
        method: 'post',
        data: {
            login_state,
            client_id: 'ibps'
        }
    })
}

/**
 * 根据authcode获取token
 * @param login_state
 */
export function getTokenByAuthcode(authorize_code) {
    return requestIBPS({
        url: `authentication/apply`,
        method: 'post',
        data: {
            authorize_code,
            client_id: 'ibps',
            client_secret: '58b65297-3467-0859-8337-8cbaf81ef68a',
            grant_type: 'authorization_code',
        }
    })
}

/**
 * 根据token获取用户信息
 */
export function getUserInfoByIbpsToken(data = {}) {
    return requestIBPS({
        url: `user/context/default`,
        method: 'post',
        data
    })
}

/**
 * 根据token获取新的service ticket
 */
export function getServiceTicketByToken() {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/get_st_by_token/`,
        method: 'get'
    })
}

/**
 * 获取用户信息，根据header["token"]处理。
 */
export function getUserInfoByToken() {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/get_info_by_token/`,
        method: 'get',
    })
}

/**
 * 根据code获取用户信息。
 * @param {code} params
 */
export function getUserInfoByCode(params) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/get_info_by_st/`,
        method: 'get',
        params
    })
}


/**
 * 根据code获取TOKEN
 * @param {code} params
 */
export function getTokenByCode(params) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/get_token_by_st/`,
        method: 'get',
        params
    })
}

/**
 * 根据ticket获取用户信息
 * @param {ticket} params
 */
export function getUserInfoByTicket(params) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/ticket/login/`,
        method: 'get',
        params
    })
}

/**
 * 获取企业微信跳转链接
 * @param String id
 */
export function getWechatUrl(id) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/auth/${id}/get_wechat_url/`,
        method: 'get'
    })
}


/**
 * 获取登录日志
 */
export function getLoger(params = {}) {
    return request({
        url: `${FRAMEWORK_AUTH_SERVICE}/loger/`,
        method: 'get',
        params
    })
}
