import request from 'string-public-design-3/utils/request'
import requestFile from 'string-public-design-3/utils/request-file'

import { FRAMEWORK_CORE_SERVICE } from "string-public-design-3/constants/location"

/**
 * 获取文件列表
 * @param {*} params 
 */
 export function queryFile(params={}) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/files/`,
        method: 'get',
        params
    })
}

/**
 * 获取文件信息
 * @param {*} fileId 
 */
 export function getFile(fileId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/files/${fileId}/`,
        method: 'get',
    })
}

/**
 * 获取图像base64格式
 * @param {*} fileId 
 * @returns 
 */
export function getImageBase64(fileId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/files/${fileId}/get_image_base64/`,
        method: 'get',
    })
}

/**
 * 获取图像数据流格式访问路径
 * @param {*} fileId 
 * @returns 
 */
export function getImageStreamURL(fileId) {
    return `${window.string.SERVICE_HOST}${FRAMEWORK_CORE_SERVICE}/files/${fileId}/get_image_stream/`;
}

/**
 * 获取上传路径
 * @returns 
 */
export function getUploadFileURL() {
    return `${window.string.SERVICE_HOST}${FRAMEWORK_CORE_SERVICE}/files/upload/`;
}

/**
 * 获取批量上传路径
 * @returns 
 */
export function getBatchUploadFileURL() {
    return `${window.string.SERVICE_HOST}${FRAMEWORK_CORE_SERVICE}/files/batch_upload/`;
}

/**
 * 获取文件下载路径
 * @param {*} fileId 
 * @returns 
 */
export function getDownloadURL(fileId) {
    return `${window.string.SERVICE_HOST}${FRAMEWORK_CORE_SERVICE}/files/${fileId}/download/`;
}

/**
 * 获取多文件下载路径
 * @param {*} fileId 
 * @returns 
 */
export function getDownloadZIP(ids) {
    return `${window.string.SERVICE_HOST}${FRAMEWORK_CORE_SERVICE}/files/batch_download/?ids=${ids}`;
}


/**
 * 删除文件
 * @param {*} fileId 
 * @returns 
 */
export function deleteFile(fileId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/files/${fileId}/delete/`,
        method: 'post',
    })
}



// TODO：废弃
export function getFilePreviewUrl(fileId) {
    return request({
        url: `${FRAMEWORK_CORE_SERVICE}/files/${fileId}/get_preview_url/`,
        method: 'get',
    })
}
