import {
    queryBaseData,
    queryBaseDataVersion
} from "string-public-design-3/api/framework/base-data/index.js"
import {getData} from "string-public-design-3/utils/cache/db"


import utils from "string-public-design-3/utils/util"

function getBaseTemplateData(module) {
    switch (module) {
        case "CONFIG":
            return [
                {code: "PLATFORM_PARAMS", version: "", value: ""},
                {code: "AUTH_SETTING", version: "", value: ""},
                {code: "FILE_SETTING", version: "", value: ""},
                {code: "WORKFLOW_SETTING", version: "", value: ""},
            ]
        case "PORTAL":
            return [
                {code: "PORTAL_LAYOUT", version: "", value: ""},
                {code: "PORTAL_IMAGE", version: "", value: ""},
                {code: "PORTAL_MODULE", version: "", value: ""}
            ]
        case "PC-APP":
            return [
                {code: "APP", version: "", value: ""},
                {code: "APP_TAG", version: "", value: ""},
                {code: "APP_CATEGORY", version: "", value: ""}
            ]
        case "MOBILE-APP":
            return [
                {code: "APP_TAG", version: "", value: ""},
                {code: "APP_CATEGORY", version: "", value: ""}
            ]
    }
}


export function getBaseData(module) {
    let localData = getData(module);
    if (!localData) {
        localData = getBaseTemplateData(module);
    }

    return new Promise((resolve, reject) => {
        // 检查数据版本
        queryBaseDataVersion().then(res => {
            // 远程数据以及版本
            let remoteDataVersion = res.data;

            // 检查需要更新的数据
            let changedDataCodes = []
            if (remoteDataVersion) {
                for (let [code, version] of Object.entries(remoteDataVersion)) {
                    let localItem = localData.find(item => item.code == code)
                    if (localItem) {
                        // 如果当前配置版本不符合，并且没有值。
                        if (localItem.version != version || utils.isEmpty(version) || utils.isEmpty(localItem.value)) {
                            // console.log(`TO UPDATE CONFIG：${code}    LOCAL: ${localItem.version}     REMOTE: ${version}`);
                            changedDataCodes.push(code)
                        }
                        // 设置版本，始终以远程版本为主。
                        localItem.version = version
                    }
                }
            }


            // 执行更新
            if (changedDataCodes.length == 0) {
                resolve(localData);
            } else {
                queryBaseData(changedDataCodes).then(res2 => {
                    if (res2.state == 200) {
                        let remoteData = res2.data;
                        for (let [code, data] of Object.entries(remoteData)) {
                            let localItem = localData.find(item => item.code == code)
                            if (localItem) {
                                // 变更版本号和数据
                                localItem.version = res2.data.VERSION[code];
                                if (localItem.code == "APP" || localItem.code == "APP_TAG" || localItem.code == "APP_CATEGORY") {
                                    localItem.value = data;
                                } else {
                                    if (data) localItem.value = JSON.parse(data.value)
                                }
                            }
                        }
                        resolve(localData);
                    } else {
                        reject(res2.message)
                    }
                })
            }
        })
    })
}
