import router from '@/router'
import store from '@/store'

// TOKEN 缓存
import {removeToken} from '@/utils/auth'
import {removeStringToken} from "@/utils/string/auth"
import util from '@/utils/util.js'

// STRING PUBLIC DESIGIN 方法
import utils from "../utils/util";
import {gotoLoginPage} from "../utils/auth"
import {Message} from "element-ui";
import {getUrlParamByKey, sortUrlParam} from "../utils/util.url";
import {getValueByKey, setValueByKey} from '../utils/cache/auth'
import {STRING_LOGIN_TICKET_KEY} from '../constants/auth'

function showMessage(message) {
    Message.error(message)
}

// 不重定向白名单
const whiteList = ['/register', '/forget', '/authredirect', '/401', '/403', '/404', '/nomenu', '/locking']


router.beforeEach(async (to, from, next) => {

    // 设置路由守卫开启时间
    let startRouterTime = Date.now();
    store.commit('ibps/waterfall/setRouterStartTime', startRouterTime)


    // 检查是否为白名单页面
    if (window.string.ROUTE_WHITE_LIST.indexOf(to.path) !== -1 || whiteList.indexOf(to.path) !== -1) {
        // 设置路由守卫结束时间
        let endRouterTime = Date.now();
        store.commit('ibps/waterfall/setRouterEndTime', endRouterTime)
        return next();
    }

    // 检查页面是否需要验证
    if ((to.meta.isAuth && to.meta.isAuth == true)) {
        // 设置路由守卫结束时间
        let endRouterTime = Date.now();
        store.commit('ibps/waterfall/setRouterEndTime', endRouterTime)
        return next();
    }

    // 单点登录处理参数顺序
    sortUrlParam()


    // 检查用户身份
    let startCheckUserTokenTimestamp = new Date().getTime();
    let ticket = getUrlParamByKey()
    const localTicket = getValueByKey(STRING_LOGIN_TICKET_KEY)
    if (ticket && ((localTicket && ticket !== localTicket) || !localTicket)) {//存在ticket，并且和本地的ticket不一致，强制重新登录
        setValueByKey(STRING_LOGIN_TICKET_KEY, ticket)
        await store.dispatch("string/auth/funLoginByStringST", ticket).catch(ex => {
            showMessage(ex.message);
        })
    } else {//不存在ticket或获取的ticket和本地的一致，判断本地登录信息
        // 情况1:如果不存在token
        if (utils.isEmpty(store.getters.stringToken) || utils.isEmpty(store.getters.ibpsToken)) {
            let vm = null;
            await store.dispatch("ibps/account/logoff", {vm}).catch(ex => {
                showMessage(ex.message);
            });
            gotoLoginPage();
        }
        // 情况2:如果存在token
        else {
            // 检查token是否过期
            await store.dispatch("string/auth/checkStringTokenValid").catch(ex => {
                showMessage(ex);
            });
            await store.dispatch("string/auth/checkIBPSTokenValid").catch(ex => {
                showMessage(ex);
            });

            // 如果token已经过期
            if (store.getters.isStringTokenValid == false || store.getters.isIBPSTokenValid == false) {
                // 删除缓存信息
                removeToken();
                removeStringToken();
                let vm = null;
                await store.dispatch("ibps/account/logoff", {vm}).catch(ex => {
                    showMessage(ex.message);
                });
                gotoLoginPage();
            }
        }
    }


    let endCheckUserTokenTimestamp = new Date().getTime()
    console.log(`==========验证用户 ${endCheckUserTokenTimestamp - startCheckUserTokenTimestamp}===========`)

    // 获取基础配置
    let startConfigTimestamp = new Date().getTime()
    await store.dispatch("config/getConfig").catch(ex => {
        console.log(ex)
    });
    let endConfigTimestamp = new Date().getTime()
    console.log(`==========获取基础配置 ${endConfigTimestamp - startConfigTimestamp}===========`)

    // 系统级别的设置
    await store.dispatch('ibps/page/isLoaded') // 加载多标签页数据，时间：10ms。
    await store.dispatch('ibps/size/isLoaded') // 加载组件尺寸设置，时间：10ms。
    store.commit('ibps/search/set', false) // 关闭搜索面板，时间：瞬间。


    // 检查是否存在用户信息，菜单路由系统，如果没有则去获取。
    if (util.isEmpty(store.getters.userInfo) || util.isEmpty(store.getters.menus)) {
        //【必须】这是IBPS原生方法，加载用户信息，如果没有存储在localStorage则从数据库获取。
        // 默认系统以及菜单路由应该是以用户信息为前提的吧
        store.dispatch('ibps/user/load').then(async res => {

            // 设置当前菜单和路由，菜单是要通过当前系统ID获取的
            // 这里的菜单通过本地文件获取，那么其实【要不要系统ID无所谓了】
            store.dispatch('ibps/menu/initByFile').then(() => {
                // 根据用户菜单权限生成可访问的路由表
                if (!util.isEmpty(store.getters.menus)) {
                    const addRouters = store.getters.routers;
                    if (addRouters && addRouters.length > 0) {
                        // 动态添加可访问路由表
                        router.addRoutes(addRouters)

                        // 初始化加载或用户刷新页面后从数据库加载一系列的设置
                        // 加载了整个系统里太多太多的东西了。
                        store.dispatch('ibps/account/loadInfo', {
                            addRouters,
                            menus: store.getters.menus
                        })

                        // hack方法 确保addRoutes已完成
                        next({...to, replace: true})
                    }
                }
            });

        }).catch(ex => {
            console.log(ex);
        })
    }

    // 设置路由守卫结束时间
    let endRouterTime = Date.now();
    store.commit('ibps/waterfall/setRouterEndTime', endRouterTime)
    // 进入页面
    next()
});

router.afterEach(to => {
    util.title(to.meta.title)
})
