import router from '@/router'
import store from '@/store'

import {removeTokenByKey, removeUserInfo, removeValueByKey} from '../utils/cache/auth'
import {STRING_LOGIN_SESSION_ID_KEY, STRING_USER_INFO_KEY, STRING_USER_TOKE_KEY} from '../constants/auth'
import {sortUrlParam} from '../utils/util.url'
import {gotoLogOutPage} from '../utils/auth'
import {MessageBox} from 'element-ui'
import {normalLogin} from 'string-public-design-3/utils/util.permission'

export const designBeforeEach = (to, from) => {
  return new Promise(async (resolve, reject) => {
    // 检查是否为白名单页面
    if (window.string.ROUTE_WHITE_LIST.indexOf(to.path) !== -1) {
      return resolve()
    }

    // 检查页面是否需要验证
    if ((to.meta.isAuth && to.meta.isAuth == true)) {
      return resolve()
    }

    // 单点登录处理参数顺序
    sortUrlParam()

    await normalLogin(async (ticket) => {
      // 使用ticket获取用户信息
      let resToken = await store.dispatch('user/getUserInfoByTicket', ticket).catch(ex => {
        MessageBox.confirm('获取用户信息失败，请重新登录', '提示', {
          confirmButtonText: '立即登录',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          store.dispatch('user/logout').catch(ex => {
            console.log(ex)
          })
        }).catch(() => {

        })
        resToken = 'relogin'
      })
      if (resToken === 'relogin') return
      if (!resToken) {
        MessageBox.confirm('当前用户登录状态异常或已被禁用，请更换用户重新登录', '提示', {
          confirmButtonText: '重新登录',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(() => {
          // 清除缓存
          removeTokenByKey(STRING_USER_TOKE_KEY)
          removeUserInfo(STRING_USER_INFO_KEY)
          removeValueByKey(STRING_LOGIN_SESSION_ID_KEY)
          //前往退出登录页面
          gotoLogOutPage()
        })
      }
    })

    // 获取基础配置
    let startConfigTimestamp = new Date().getTime()
    await store.dispatch('config/getData').catch(ex => {
      console.log(ex)
    })
    let endConfigTimestamp = new Date().getTime()
    console.log(`==========获取基础配置！ ${endConfigTimestamp - startConfigTimestamp}===========`)

    // 进入页面
    resolve()
  })
}
