import { mapGetters, mapMutations } from "vuex";

export default {
    data() {
        return {
            // 选择控制
            selectAll: false,
            singleSelectId: null,
        }
    },
    props: {
        // 已选中Id列表。
        selectedIds: {
            type: Array,
            default: () => [],
        },
    },
    watch: {
        selectedNodes() {
            // 处理当前的节点是否被选中
            this.checkNodeSelected();
        },
    },
    computed: {
        ...mapGetters("selector", ["selectedNodes"]),
    },
    methods: {
        ...mapMutations("selector", ["SET_SELECTED_NODES"]),

        // 全选/反选所有节点
        onChangeSelectAllNode(checked) {
            this.nodes.forEach((item) => {
                if(item.enable){
                    item.selected = checked;
                }
            });

            // 筛选出可以用的节点
            let nodes = this.nodes.filter(item=>item.enable==true);
            if (checked) {
                // 新增已经选择的节点
                this.addSelectedNode(nodes);
            } else {
                // 删除已经选择的节点
                this.removeSelectedNode(nodes);
            }
        },

        // 选择/反选单节点
        onChangeSelectNode(checked) {
            if (this.isSingle) {
                let node = this.nodes.find((item) => item.id == this.singleSelectId && item.enable);
                if (node) {
                    this.SET_SELECTED_NODES([node]);
                } else {
                    this.SET_SELECTED_NODES([]);
                }
            } else {
                if (checked) {
                    // 新增已经选择的节点
                    let selectedNodesThisTime = this.nodes.filter(
                        (item) => item.selected == true && item.enable
                    );
                    this.addSelectedNode(selectedNodesThisTime);
                } else {
                    // 删除已经选择的节点
                    let removedNodesThisTime = this.nodes.filter(
                        (item) => item.selected == false && item.enable
                    );
                    this.removeSelectedNode(removedNodesThisTime);
                }
            }
        },

        // 选择/反选单节点的名称
        onSwitchNode(node) {
            if(!node.enable){
                return false;
            }
            if (this.isSingle) {
                this.singleSelectId =
                    this.singleSelectId == node.id ? null : node.id;
                if (this.singleSelectId) {
                    this.SET_SELECTED_NODES([node]);
                } else {
                    this.SET_SELECTED_NODES([]);
                }
            } else {
                node.selected = !node.selected;
                if (node.selected) {
                    // 新增已经选择的节点
                    this.addSelectedNode([node]);
                } else {
                    // 删除已经选择的节点
                    this.removeSelectedNode([node]);
                }
            }
        },

        // 新增历史节点
        // 保留历史节点获取非重复的节点
        addSelectedNode(nodes) {
            // 合并节点
            let tempNodes = [...this.selectedNodes, ...nodes];

            // 去重复
            let hash = {};
            let tempNodes2 = tempNodes.reduce((preVal, curVal) => {
                hash[curVal.id]	
                  ? ""
                  : (hash[curVal.id] = true && preVal.push(curVal));
                return preVal;
              }, []);

            this.SET_SELECTED_NODES(tempNodes2);
        },
        // 移除历史节点
        removeSelectedNode(nodes) {
            // 处理选择节点
            let tempNodes = [...this.selectedNodes];
            nodes.forEach((item) => {
                let deletedIndex = tempNodes.findIndex((node) => node.id == item.id);
                if (deletedIndex != -1) {
                    tempNodes.splice(deletedIndex, 1);
                }
            });
            this.SET_SELECTED_NODES(tempNodes);
        },

        // 处理当前的节点是否被选中
        checkNodeSelected() {
            // 检查每个节点目前的选择情况
            this.nodes.forEach((node) => {
                // 检查是否选中
                let selectedNode = this.selectedNodes.find(
                    (item) => item.id == node.id
                );
                if (selectedNode) {
                    node.selected = true;
                } else {
                    node.selected = false;
                }
            });
            // 检查是否节点被全选了
            let selectedNodeCount = this.nodes.filter(
                (item) => item.selected == true
            ).length;
            this.selectAll = selectedNodeCount == this.nodes.length;
            this.singleSelectId =
                selectedNodeCount == 0 ? null : this.singleSelectId;
        },

        // 检查数据初始化是否选中
        checkNodeEnable(item) {
            // 检查已经被用户选择
            let index = this.selectedIds.findIndex((id) => id == item.id);
            return index == -1 ? true : false;
        },
    }
}