/**
 * 公共的配置项
 * 包含：平台信息配置、身份认证配置、文件信息配置、流程配置
 */

import * as dd from 'dingtalk-jsapi';

import { getBaseData } from "string-public-design-3/methods/cache"
import { setData } from "string-public-design-3/utils/cache/db"

const MODULE_NAME = "CONFIG";

// 判断移动端操作系统
function getMobileOS() {
    let mobileOS = ""
    let u = navigator.userAgent;
    if (u.indexOf('Android') > -1 || u.indexOf('Linux') > -1) {
        mobileOS = "Android"
    } else if (u.indexOf('iPhone') > -1) {
        mobileOS = "iOS"
    }
    return mobileOS
}

// 判断移动端浏览器环境，如钉钉、微信
function getMobileEnv() {
    let mobileEnv = "h5"
    let u = navigator.userAgent.toLowerCase();
    if (u.indexOf('micromessenger') > -1) {
        mobileEnv = "weChat"
    } else if (dd.env.platform !== 'notInDingTalk') {
        mobileEnv = "dingTalk"
    }
    return mobileEnv
}

const state = {
    mobileOS: getMobileOS(), // 移动端操作系统
    mobileEnv: getMobileEnv(), // 移动端环境

    db: null
}

const getters = {
    mobileOS: state => state.mobileOS,
    mobileEnv: state => state.mobileEnv,

    platformConfig: state =>state.db ?  state.db.find(item => item.code == "PLATFORM_PARAMS").value:[],
    authConfig: state =>state.db ?  state.db.find(item => item.code == "AUTH_SETTING").value:[],
    fileConfig: state =>state.db ?  state.db.find(item => item.code == "FILE_SETTING").value:[],
    workflowConfig: state => state.db ? state.db.find(item => item.code == "WORKFLOW_SETTING").value:[]
}

const mutations = {
    SET_DB: (state, db) => {
        state.db = db
    }
}

const actions = {
    getData({ state, commit }) {
        return new Promise((resolve, reject) => {
            getBaseData(MODULE_NAME).then((data) => {
                commit("SET_DB", data)
                setData(MODULE_NAME, data)
                resolve()
            })
        }).catch(ex => {
            reject(ex);
            console.log(ex);
        })
    }
}

export default {
    namespaced: true,
    state,
    getters,
    mutations,
    actions
}


