import {logout, getTokenByCode, mobileLogin,loginDing,  checkCasLoginValiation, getUserInfoByTicket} from 'string-public-design-3/api/framework/auth/index.js'

import {queryUserUnitedApp} from "string-public-design-3/api/framework/account/user.js"

import {setTokenByKey, getTokenByKey, removeTokenByKey, removeValueByKey, setValueByKey, removePerms} from 'string-public-design-3/utils/cache/auth'
import {setUserInfo, getUserInfo as getUserInfoFromCache, removeUserInfo} from 'string-public-design-3/utils/cache/auth'
import {setUserConfig, getUserConfig as getUserConfigFromCache} from 'string-public-design-3/utils/cache/auth'

import {gotoLoginPage, gotoMobileLoginPage, gotoLogOutPage,gotoWechatOauth2Page} from 'string-public-design-3/utils/auth'

import store from '@/store'
import {
    STRING_USER_TOKE_KEY,
    STRING_USER_INFO_KEY,
    STRING_USER_CONFIG_KEY,

    STRING_PERMISSION_KEY,
    STRING_LOGIN_TICKET_KEY,
    STRING_LOGIN_SESSION_ID_KEY,
    STRING_CURRENT_PERMISSION_KEY
} from 'string-public-design-3/constants/auth'

const state = {
    token: getTokenByKey(STRING_USER_TOKE_KEY),
    isTokenValid: false,
    userInfo: getUserInfoFromCache(STRING_USER_INFO_KEY),

    userConfig: getUserConfigFromCache(STRING_USER_CONFIG_KEY),

    userApp: {
        assignedIdList: [],
        favouriteIdList: [],
        recommendIdList: [],
        recentIdList: [],
        manageIdList: [],
    }
}

const getters = {
    token: state => state.token,
    isTokenValid: state => state.isTokenValid,
    userInfo: state => state.userInfo ? state.userInfo : null,
    userConfig: state => state.userConfig,

    userApp: state => state.userApp,
}

const mutations = {
    SET_TOKEN: (state, token) => {
        state.token = token
        if (token) {
            setTokenByKey(STRING_USER_TOKE_KEY, token)
        } else {
            removeTokenByKey(STRING_USER_TOKE_KEY)
        }

    },
    SET_TOKEN_VALID: (state, isTokenValid) => {
        state.isTokenValid = isTokenValid
    },

    SET_USER_INFO: (state, userInfo) => {
        state.userInfo = userInfo
        if (userInfo) {
            setUserInfo(STRING_USER_INFO_KEY, userInfo)
        } else {
            removeUserInfo(STRING_USER_INFO_KEY)
        }
    },

    SET_USER_CONFIG: (state, config) => {
        state.userConfig = config
        if (config) {
            setUserConfig(STRING_USER_CONFIG_KEY, config)
        } else {
            setUserConfig(STRING_USER_CONFIG_KEY)
        }
    },

    SET_USER_APP: (state, userApp) => {
        state.userApp = userApp
    },
}

const actions = {

    /**
     * 检查当前登录是否有效
     * @param {*} param0
     */
    checkTicketValid({commit, dispatch}) {
        return new Promise((resolve, reject) => {
            // const sessionId = getValueByKey(STRING_LOGIN_SESSION_ID_KEY)
            // const domain = window.location.hostname
            // const path = window.location.pathname
            checkCasLoginValiation({}).then(resp => {
                if (resp.state === 200) {
                    if (!resp.data.outOfTime) {//登录有效
                        commit('SET_TOKEN_VALID', true)
                        resolve(resp)
                    } else {//登录无效
                        dispatch('logout').catch(ex => {
                            console.log(ex)
                        })
                    }
                } else {
                    dispatch('logout').catch(ex => {
                        console.log(ex)
                    })
                }
            }).catch(ex => {
                dispatch('logout').catch(ex => {
                    console.log(ex)
                })
            })
        })
    },


    /**
     * 移动端登录
     */
    mobileLogin({commit}, data) {
        removeUserInfo(STRING_USER_INFO_KEY)
        return new Promise((resolve, reject) => {
            mobileLogin(data).then(resp => {
                if (resp.state == 200) {
                    // 存储TOKEN
                    commit('SET_TOKEN', resp.data.token)
                    // 写入日志
                    resolve({code: 1, message: 'login success'})
                    // 存储用户信息
                    let userInfo = resp.data.userInfo
                    commit('SET_USER_INFO', userInfo)
                    // userInfo.roles.length = 0
                    // userInfo.rolesInfo.length = 0
                    setUserInfo(STRING_USER_INFO_KEY, userInfo)
                } else {
                    reject({code: 2, message: 'login failed:token is empty'})
                }
            }).catch(ex => {
                reject({code: 2, message: ex})
            })
        })
    },
    /**
     * 移动端钉钉登录
     */
     loginDing({commit}, data) {
        removeUserInfo(STRING_USER_INFO_KEY)
        return new Promise((resolve, reject) => {
            loginDing(data).then(resp => {
                if (resp.state == 200) {
                    // 存储TOKEN
                    commit('SET_TOKEN', resp.data.token)
                    // 写入日志
                    resolve({code: 1, message: 'login success'})
                    // 存储用户信息
                    let userInfo = resp.data.userInfo
                    commit('SET_USER_INFO', userInfo)
                    // userInfo.roles.length = 0
                    // userInfo.rolesInfo.length = 0
                    setUserInfo(STRING_USER_INFO_KEY, userInfo)
                } else {
                    reject({code: 2, message: 'login failed:token is empty'})
                }
            }).catch(ex => {
                reject({code: 2, message: ex})
            })
        })
    },


    /**
     * 登录：通过单点登录方式处理
     * 通过service ticket来换取token
     * @param {*} param0
     * @param {*} st
     */
    login({commit}, st) {
        removeUserInfo(STRING_USER_INFO_KEY)
        return new Promise((resolve, reject) => {
            let url = window.location.href//new-login
            let search = window.location.search//new-login
            let redirectUrl = url.replace(search, '')//new-login
            let loginURL = redirectUrl.split('#')[0].replace(/&ticket=(\S*)/g, '')//new-login
            getTokenByCode({ticket: st, reqUrl: loginURL}).then(resp => {//new-login
                // getTokenByCode({ code: st }).then(resp => {
                // 访问接口成功
                if (resp.state == 200) {
                    setValueByKey(STRING_LOGIN_SESSION_ID_KEY, resp.data.sessionId)//new-login
                    checkCasLoginValiation({sessionId: resp.data.sessionId})//new-login
                    if (resp.data) {
                        // 存储token
                        let token = resp.data.token//new-login

                        commit('SET_TOKEN', token)
                        // 存储用户信息
                        commit('SET_USER_INFO', resp.data.userInfo)
                        // 存储用户配置信息
                        commit('SET_USER_CONFIG', resp.data.settings?JSON.parse(resp.data.settings.value):null)
                        // 处理完成
                        resolve({code: 1, message: 'login success'})
                    } else {
                        this.$message.error('登陆失败！')
                        reject({code: 2, message: 'login failed:token is empty'})
                    }
                } else {
                    reject({code: 2, message: 'login failed:can\'t get the token,maybe the ST is expired'})
                }
            }).catch(ex => {
                reject({code: 2, message: ex})
            })

        })
    },

    /**
     * 需要清空SSO系统中的登录信息
     * 这个方法是进入登录页面
     * @param {*} param0
     */
    logout({commit}) {
        return new Promise((resolve, reject) => {
            // 执行接口进行缓存清空
            logout().then(resp => {
                if (resp.state == 200) {
                    // 清除缓存
                    removeTokenByKey(STRING_USER_TOKE_KEY);
                    removeUserInfo(STRING_USER_INFO_KEY);
                    localStorage.removeItem(STRING_USER_INFO_KEY); // 防止历史原因，未删除localStorage
                    console.log("===remove the localstorage user info always===");
                    removeValueByKey(STRING_PERMISSION_KEY);
                    removeValueByKey(STRING_LOGIN_SESSION_ID_KEY)
                    commit('SET_TOKEN', null);
                    commit('SET_USER_INFO', null);

                    //清除ibps缓存

                    //判断登录如果是企业微信则走企业微信重新认证
                    let authConfig = store.getters['config/authConfig']
                    console.log("token过期")
                    switch (authConfig.mobileLoginMethod) {
                        case 'WECHAT'://企业微信
                            gotoWechatOauth2Page(authConfig.mobileWechatAppId)
                            break
                        default:
                            //前往登录页面
                            gotoLoginPage()
                            break
                    }
                    // 处理完成
                    // resolve(resp)
                } else {
                    reject(resp)
                }

            }).catch(ex => {
                console.log(ex)
                reject(ex)
            })
        })
    },

    /**
     * 需要清空SSO系统中的登录信息
     * 这个方法是进入登录页面
     * @param {*} param0
     */
    logoutMobile({commit}) {
        return new Promise((resolve, reject) => {
            // 执行接口进行缓存清空
            logout().then(resp => {
                if (resp.state == 200) {
                    // 清除缓存
                    removeTokenByKey(STRING_USER_TOKE_KEY);
                    removeUserInfo(STRING_USER_INFO_KEY);
                    localStorage.removeItem(STRING_USER_INFO_KEY); // 防止历史原因，未删除localStorage
                    console.log("===remove the localstorage user info always===");
                    removeValueByKey(STRING_PERMISSION_KEY);
                    commit('SET_TOKEN', null);
                    commit('SET_USER_INFO', null);
                    //前往登录页面
                    gotoMobileLoginPage()
                    // 处理完成
                    resolve(resp)
                } else {
                    reject(resp)
                }

            }).catch(ex => {
                console.log(ex)
                reject(ex)
            })
        })
    },

    /**
     * 专门注销：需要清空SSO系统中的登录信息
     * 这个方法是进入注销页面
     * @param {*} param0
     */
    logOff({commit}) {
        return new Promise((resolve, reject) => {
            // 执行接口进行缓存清空
            logout().then(resp => {
                if (resp.state == 200) {
                    // 清除缓存
                    removeTokenByKey(STRING_USER_TOKE_KEY);
                    removeUserInfo(STRING_USER_INFO_KEY);
                    localStorage.removeItem(STRING_USER_INFO_KEY); // 防止历史原因，未删除localStorage
                    console.log("===remove the localstorage user info always===");
                    removeValueByKey(STRING_PERMISSION_KEY);
                    commit('SET_TOKEN', null);
                    commit('SET_USER_INFO', null);
                    // 前往登出页面
                    gotoLogOutPage()
                    //处理完成
                    resolve(resp)
                } else {
                    reject(resp)
                }

            }).catch(ex => {
                console.log(ex)
                reject(ex)
            })
        })
    },

    // 通过ticket获取用户信息
    getUserInfoByTicket({state, commit, dispatch}, st) {
        removeUserInfo(STRING_USER_INFO_KEY);
        removePerms(STRING_CURRENT_PERMISSION_KEY);
        return new Promise((resolve, reject) => {
            let url = window.location.href
            let search = window.location.search
            let redirectUrl = url.replace(search, '')
            let loginURL = redirectUrl.split('#')[0].replace(/&ticket=(\S*)/g, '')
            getUserInfoByTicket({ticket: st, reqUrl: loginURL}).then(resp => {
                // 访问接口成功
                if (resp.state == 200) {
                    if (resp.data) {
                        if (!resp.data.token) {
                            return resolve(null)
                        }
                        //存储JSESSIONID
                        setValueByKey(STRING_LOGIN_SESSION_ID_KEY, resp.data.sessionId)
                        //存储ticket
                        setValueByKey(STRING_LOGIN_TICKET_KEY, resp.data.st)
                        // 存储token
                        let token = resp.data.token
                        commit('SET_TOKEN', token)
                        // 存储用户信息
                        let userInfo = resp.data.userInfo
                        commit('SET_USER_INFO', userInfo)
                        // 存储用户配置信息
                        commit('SET_USER_CONFIG', resp.data.settings?JSON.parse(resp.data.settings.value):null)
                        setUserInfo(STRING_USER_INFO_KEY, userInfo)
                        // 处理完成
                        resolve(resp.data.token)
                    } else {
                        reject({code: 2, message: resp.message})
                    }
                } else {
                    reject({code: 2, message: resp.message})
                }
            }).catch(ex => {
                reject({code: 2, message: ex})
            })
        })
    },

    // 获取用户应用，包含授权的，推荐的，收藏的等等
    getUserApps({state, commit}) {
        return new Promise((resolve, reject) => {
            queryUserUnitedApp(state.userInfo.id).then(resp => {
                // 获取用户配置的应用
                if (resp.state == 200) {
                    // 设置用户APP
                    commit("SET_USER_APP", resp.data);
                    // 处理完成
                    resolve({code: 1, message: resp.message})
                } else {
                    reject({code: 2, message: resp.message});
                }

            }).catch(ex => {
                reject({code: 2, message: ex});
            })

        })
    }
}

export default {
    namespaced: true,
    state,
    getters,
    mutations,
    actions
}

