/**
 * 访问API的公共方法
 * 依赖：1-配置文件中的SERVICE_HOST属性、2-VUEX中store.user.token属性。
 */

import axios from 'axios'
import store from '@/store'

const service = axios.create({
    headers: {
        //当只设置cacahe-control: 'no-cache'时，IE浏览器始终返回304，抓包工具抓不到包，请求不和服务器确认
        //当只设置cacahe-control: 'no-cache'时，google浏览器始终返回200，抓包工具可以抓取包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
        'cache-control': 'no-cache',
        //当只设置Pragma: 'no-cache'时，IE浏览器始终返回200，抓包工具可以抓到所有包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
        //当只设置Pragma: 'no-cache'时，google浏览器始终返回200，抓包工具可以抓到所有包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
        'Pragma': 'no-cache'
    },
    baseURL: window.string.SERVICE_HOST,
    withCredentials: false, // 表示跨域请求时是否需要使用凭证
    timeout: 30 * 10000 // 30秒超时
})

service.interceptors.request.use(
    config => {
        config.headers['Content-Type'] = 'multipart/form-data'
        if (store.state.user) {
            config.headers['token'] = store.state.user.token
        }

        if(config.method==='get' || 'post'){
            config.params={
              timestamp3:new Date().getTime(),
              ...config.params
            }
          }
          
        return config
    },
    error => {
        console.log(error)
        return Promise.reject(error)
    }
)

service.interceptors.response.use(
    async response => {
        const res = response.data;
        if (res.state === 401) {
            await store.dispatch("user/logout").catch(ex => {
                console.log(ex);
            });
        }
        return res
    },
    error => {
        console.log(error)
        return Promise.reject(error)
    }
)

export default service

