import axios from 'axios'
import store from '@/store'

const service = axios.create({
    headers: {
        //当只设置cacahe-control: 'no-cache'时，IE浏览器始终返回304，抓包工具抓不到包，请求不和服务器确认
        //当只设置cacahe-control: 'no-cache'时，google浏览器始终返回200，抓包工具可以抓取包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
        'cache-control': 'no-cache',
        //当只设置Pragma: 'no-cache'时，IE浏览器始终返回200，抓包工具可以抓到所有包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
        //当只设置Pragma: 'no-cache'时，google浏览器始终返回200，抓包工具可以抓到所有包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
        'Pragma': 'no-cache'
    },
    baseURL: window.string.IBPS_SERVICE_HOST,
    withCredentials: false, // 表示跨域请求时是否需要使用凭证
    timeout: 30 * 1000 // 30秒超时
})

// 是否正在刷新的标记
let isRefreshing = false
// 重试队列，每一项将是一个待执行的函数形式
let requests = []

// request interceptor
service.interceptors.request.use(
    config => {
        if(store.state.user.ibpsToken){
            config.headers['X-Authorization-access_token'] = store.state.user.ibpsToken;
        }

        if(config.method==='get' || 'post'){
            config.params={
                timestamp3:new Date().getTime(),
                ...config.params
            }
        }
        return config
    },
    error => {
        console.log(error)
        return Promise.reject(error)
    }
)

// response interceptor
service.interceptors.response.use(
    response => {
        const res = response.data;
        return res
    },
    error => {
        console.log(error)
        return Promise.reject(error)
    }
)

export default service
