import axios from 'axios'
import { MessageBox, Message } from 'element-ui'
import store from '@/store'
// import { getToken } from '@/utils/cache/auth'

// create an axios instance
const service = axios.create({
  baseURL: window.string.HELP_SERVICE_API, // url = base url + request url
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 5000000 // request timeout
})

// request interceptor
service.interceptors.request.use(
  config => {
    // do something before request is sent

    if (store.getters.token) {
      // let each request carry token
      // ['X-Token'] is a custom headers key
      // please modify it according to the actual situation
      config.headers['X-Token'] = ""
    }

    if(config.method==='get' || 'post'){
      config.params={
        timestamp3:new Date().getTime(),
        ...config.params
      }
    }
    
    return config
  },
  error => {
    // do something with request error
    console.log(error) // for debug
    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
  */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    const res = response;
    if(res.status == 401){
        Message({
            message: "您的权限验证失败！请重新登录！",
            type: 'error',
            duration: 5 * 1000
        })
    }
    if(res.status == 500){
      Message({
          message: response.statusText,
          type: 'error',
          duration: 5 * 1000
      })
  }
    return response
  },
  error => {
    console.log('err' + error) // for debug
    Message({
      message: error.message,
      type: 'error',
      duration: 5 * 1000
    })
    return Promise.reject(error)
  }
)

export default service
