import store from '../../../store/index.js'

let showModal = false

/**
 * 定义请求失败返回参数
 * */
const errorRes = {
    state: 9999,
    message: '请求失败',
    data: null
}


/**
 * 处理返回异常接口
 * */
function requestError(res) {

}

function requestFn(method, url, data = {}, headers = {}) {
    return new Promise((resolve, reject) => {
        //检查网络连接状态
        uni.getNetworkType({
            success: function (res) {
                if (res.networkType === 'none') { //没有连接网络
                    if (!showModal) {
                        showModal = true;
                        uni.showModal({
                            title: '网络异常',
                            content: '请检测网络连接状态',
                            showCancel: false,
                            success: function (res) {
                                if (res.confirm) {
                                    showModal = false
                                }
                            }
                        });
                    } else {
                        resolve(errorRes)
                    }
                } else { //网络连接正常
                    let header = {
                        //当只设置cacahe-control: 'no-cache'时，IE浏览器始终返回304，抓包工具抓不到包，请求不和服务器确认
                        //当只设置cacahe-control: 'no-cache'时，google浏览器始终返回200，抓包工具可以抓取包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
                        'cache-control': 'no-cache',
                        //当只设置Pragma: 'no-cache'时，IE浏览器始终返回200，抓包工具可以抓到所有包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
                        //当只设置Pragma: 'no-cache'时，google浏览器始终返回200，抓包工具可以抓到所有包，请求重新从服务器获取数据，没有利用到浏览器的缓存功能
                        'Pragma': 'no-cache',
                        'token': store.state.user.token
                    };

                    //合并传过来的header
                    header = Object.assign(header, headers)

                    uni.request({
                        url, data, method, header,
                        success: (res) => {
                            if (res.statusCode === 200) {
                                resolve(res.data)
                                if (res.data.key !== 200) {
                                    requestError(res.data)
                                }
                            } else {
                                reject(errorRes)
                            }
                        },
                        fail: (err) => {
                            reject(errorRes)
                        }
                    });


                }
            }
        });
    }).catch(err => {
        console.log(err);
        if (showModal) return
        showModal = true
        uni.showModal({
            title: '提示',
            content: '服务器连接异常，请稍后重试',
            showCancel: false,
            success: function (res) {
                showModal = false
            }
        });
    })
}

export default class {
    constructor(arg) {
        this.host = arg.host
        this.headers = arg.headers ? arg.headers : {}
    }

    get(url, params = {}, headers = {}) {
        return requestFn('GET', this.host + url, params, Object.assign(this.headers, headers))
    }

    post(url, params = {}, headers = {}) {
        return requestFn('POST', this.host + url, params, Object.assign(this.headers, headers))
    }
}
