import store from '@/store'
import { getTokenByKey,setTokenByKey, getValueByKey, getUserInfo } from 'string-public-design-3/utils/cache/auth'
import { STRING_LOGIN_TICKET_KEY, STRING_USER_INFO_KEY, STRING_USER_TOKE_KEY } from 'string-public-design-3/constants/auth'
import { getUrlParamByKey } from 'string-public-design-3/utils/util.url'
import {setUserInfo} from "./cache/auth";

/**
 * 验证缓存登录信息是否存在 token、userInfo
 * 1、验证vuex中是否有token及uesrInfo
 * 2、有：验证缓存中是否有
 *        没有：将vuex中的数据存入缓存
 * */
export const validateLocalLoginInfo = () => {
  const storeToken = store.state.user.token
  const storeUserInfo = store.state.user.userInfo
  if (storeToken && storeUserInfo) {
    const storageToken = getTokenByKey(STRING_USER_TOKE_KEY)
    const storageUserInfo = getUserInfo(STRING_USER_INFO_KEY)
    if (!storageToken || !storageUserInfo) {
      setTokenByKey(STRING_USER_TOKE_KEY, storeToken)
      setUserInfo(STRING_USER_INFO_KEY, storeUserInfo)
    }
    return true
  }
  return false
}

/**
 * 普通cas登录方式
 * 登录流程：判断地址栏是否存在ticket，如果存在，则是已经登录完成重定向回来，直接使用ticket登录并换取用户信息
 *          如果不存在，则判断缓存中是否存在登录信息，如果有，验证有效性，没有则跳转到登录页
 * */
export const normalLogin = async (callback) => {
  const ticket = getUrlParamByKey()
  if (ticket) {
    //获取本地的ticket
    let localTicket = getValueByKey(STRING_LOGIN_TICKET_KEY)
    if (localTicket && localTicket === ticket) {
      // 校验当前登录有效性
      await store.dispatch('user/checkTicketValid').catch(ex => {
        console.log(ex)
      })
      callback(false)
    } else {
      callback(ticket)
    }
  } else {
    if (!validateLocalLoginInfo()) {
      await store.dispatch('user/logout').catch(ex => {
        console.log(ex)
      })
    } else {
      // 校验当前登录有效性
      await store.dispatch('user/checkTicketValid').catch(ex => {
        console.log(ex)
      })
    }
    callback(false)
  }
}
