//通过key值获取地址栏参数，默认ticket
export function getUrlParamByKey(key = 'ticket') {
  let href = window.location.href
  if (key === 'token') href = decodeURIComponent(href)
  if (href.indexOf(key + '=') === -1) return false//不包含，直接返回false
  let urlParams = href.split(`${key}=`)[1]
  let paramsStrList = urlParams.split('&')
  let value = paramsStrList[0]
  if (!value) {
    let reg = new RegExp(`${key}=(\\S*)#/`, "g")
    if (reg.test(href)) {
      let str = href.match(reg)[0]
      reg = new RegExp(`(${key}=)|#/`, "g")
      value = str.replace(reg, '')
    }
  } else {
    if (value.indexOf('#/') > -1) {
      value = value.split('#/')[0]
    }
  }
  return value
}


//地址栏参数排序，目的是把重定向页面地址里#前面的指定参数拿到后面拼接成正常参数
export function sortUrlParam(key = 'ticket') {
  // 单点登录处理参数顺序
  // if (window.location.href.indexOf(`${key}=`) > -1) {
  //   let reg = new RegExp(`${key}=\\S*.#/`, "")
  //   if (reg.test(window.location.href)) {
  //     let search = window.location.search
  //     let hash = window.location.hash.replace(/(#\/\S*.#\/)/g, '').replace(/#\//g, '')
  //     let url = window.location.origin + window.location.pathname
  //     let href = url + '#/' + hash + search
  //     window.history.replaceState( null, null, href );
  //   }
  // }
  let url = formatUrl(window.location.href);
  window.history.replaceState(null, null, url);
}


//截取地址栏域名(包含路径)
function getDomainBySplitUrl(url) {
  let index = url.indexOf('?');
  let domain = url;
  if (index > -1) domain = url.substring(0, index);
  index = url.indexOf('#');
  if (index > -1) domain = domain.substring(0, index);
  return domain;
}


//截取地址栏路由地址
function getRouteStrBySplitUrl(url) {
  let index1 = url.indexOf('?');
  let index2 = url.indexOf('#');
  let routeStr = '';
  //判断?和#哪个在前用哪个开始截取
  if (index1 !== index2) {
    if (index1 === -1) routeStr = url.substring(index2);
    else if (index2 === -1) routeStr = '';
    else routeStr = url.substring(index1 > index2 ? index2 : index1);
    routeStr = routeStr.replace(/\?\S*#/, '');
    //获取到的字符串中可能会存在#或?,需要处理掉
    let index = routeStr.indexOf('?');
    if (index > -1) routeStr = routeStr.substring(0, index);
    index = routeStr.indexOf('#');
    if (index > -1) routeStr = routeStr.substring(index + 1);
  }
  ;
  if (routeStr === '') routeStr = '/';
  return routeStr;
}


//截取地址栏第一部分参数，及路由之前的参数
function getFirstParamObjBySplitUrl(url) {
  let resultList = url.match(/\?\S*#/);
  let firstParam = '';
  if (resultList && resultList.length > 0) {
    firstParam = resultList[0];
    firstParam = firstParam.replace(/#\/\S*#/, '');
    firstParam = firstParam.replace(/#/g, '');
  }
  let firstParamObj = {};
  if (firstParam === '') firstParamObj = null;
  else {
    let firstParamStrList = firstParam.split(/[?&]/);
    for (let value of firstParamStrList) {
      if (value !== '') {
        firstParamObj[value.split('=')[0]] = value.split('=')[1];
      }
    }
  }
  return firstParamObj;
}


//截取地址栏第二部分参数，及路由之后的参数
function getLastParamObjBySplitUrl(url) {
  let lastParamObj = {};
  let index = url.indexOf('?');
  if (index > -1) {
    let lastParamStr = url.substring(index);
    index = lastParamStr.indexOf('#');
    if (index > -1) lastParamStr = lastParamStr.substring(index + 1);
    index = lastParamStr.indexOf('#');
    if (index > -1) lastParamStr = lastParamStr.substring(index + 1);
    lastParamStr = lastParamStr.replace(getRouteStrBySplitUrl(url), '');
    let lastParamStrList = lastParamStr.split(/[?&]/);
    for (let value of lastParamStrList) {
      if (value !== '') {
        lastParamObj[value.split('=')[0]] = value.split('=')[1];
      }
    }
  } else {
    lastParamObj = null;
  }
  return lastParamObj;
}


//地址栏参数排序，目的是把重定向页面地址里#前面的指定参数拿到后面拼接成正常参数
function formatUrl(url) {
  let domain = getDomainBySplitUrl(url);
  let routeStr = getRouteStrBySplitUrl(url);
  let firstParamObj = getFirstParamObjBySplitUrl(url);
  let lastParamObj = getLastParamObjBySplitUrl(url);
  //合并参数
  let obj = Object.assign(firstParamObj || {}, lastParamObj || {});
  let paramStr = '';
  for (let key in obj) {
    paramStr += paramStr === '' ? `?${key}=${obj[key]}` : `&${key}=${obj[key]}`;
  }
  return `${domain}#${routeStr}${paramStr}`;
}
